Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6376)

Unified Diff: chrome/browser/chromeos/login/screens/base_screen.h

Issue 763563002: Implemented event-dispatching for button clicks. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase. Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/chromeos/login/screens/base_screen.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/login/screens/base_screen.h
diff --git a/chrome/browser/chromeos/login/screens/base_screen.h b/chrome/browser/chromeos/login/screens/base_screen.h
index 11a6618849f42e3bf3b5e56c050c9aae8d20bf56..d9b36e5a757c661bff0959b7def3649f31eb3fb7 100644
--- a/chrome/browser/chromeos/login/screens/base_screen.h
+++ b/chrome/browser/chromeos/login/screens/base_screen.h
@@ -78,9 +78,10 @@ class BaseScreen {
// it's work with |outcome|.
void Finish(BaseScreenDelegate::ExitCodes exit_code);
- // Called when button with |button_id| was pressed. Notification
- // about this event comes from the JS counterpart.
- virtual void OnButtonPressed(const std::string& button_id);
+ // Called when user action event with |event_id|
+ // happened. Notification about this event comes from the JS
+ // counterpart.
+ virtual void OnUserAction(const std::string& event_id);
// The method is called each time some key in screen context is
// updated by JS side. Default implementation does nothing, so
« no previous file with comments | « no previous file | chrome/browser/chromeos/login/screens/base_screen.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698